<template>
  <gree-popup class="air-auto-popup" position="bottom" get-container="body" v-model="isShow" safe-area-inset-bottom @hide="onHide">
    <gree-radio-list :class="{ 'is-airauto': !Pow && Air === 1 }" :value="Air" :options="radioLists" @change="onClick">
      <template slot-scope="{ option }">
        <p class="air-title">{{ option.text }}</p>
        <p class="air-describe" :class="{ 'set-gray': !Pow }">{{ option.brief }}</p>
        <div class="btn-group" v-if="option.value === 1 && !Pow && Air === 1">
          <gree-block class="btn" @click.native="onClickBtn(index)" v-for="(item, index) in btnList" :key="index">
            <gree-radio-box :class="{ 'is-checked': item.value === WdSpd }" name="1" :value="WdSpd" :label="item.text" />
          </gree-block>
        </div>
      </template>
    </gree-radio-list>
  </gree-popup>
</template>

<script>
import { popup, RadioList, RadioBox, Block } from 'gree-ui';
import { types } from '@/store/types';
import { mapState, mapMutations, mapActions } from 'vuex';

export default {
  name: 'AirAutoPopup',
  components: {
    [popup.name]: popup,
    [Block.name]: Block,

    [RadioBox.name]: RadioBox,
    [RadioList.name]: RadioList
  },
  data() {
    return {
      isShow: false,
      physique: 1
    };
  },
  computed: {
    ...mapState('control', {
      Pow: state => state.dataObject.Pow,
      Air: state => state.dataObject.Air,
      StHt: state => state.dataObject.StHt || 0,
      WdSpd: state => state.dataObject.WdSpd,
      AirAutoPopup: state => state.popup.AirAutoPopup
    }),
    btnList() {
      return [
        {
          value: 1,
          text: '低速风'
        },
        {
          value: 3,
          text: '中速风'
        },
        {
          value: 5,
          text: '高速风'
        }
      ];
    },
    radioLists() {
      return [
        {
          value: 3,
          text: '智能',
          brief: '根据环境自动开启或关闭新风',
          disabled: this.Pow ? false : true
        },
        {
          value: 1,
          text: '常开',
          brief: ''
        },
        {
          value: 0,
          text: '关闭',
          brief: ''
        }
      ];
    }
  },
  watch: {
    AirAutoPopup(val) {
      this.isShow = val;
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    ...mapActions({
      sendData: types.SEND_DATA,
      sendCtrl: types.SEND_CTRL
    }),
    onClickBtn(index) {
      switch (index) {
        case 0:
          this.sendData({ WdSpd: 1 });
          break;
        case 1:
          this.sendData({ WdSpd: 3 });
          break;
        case 2:
          this.sendData({ WdSpd: 5 });
          break;
        default:
          break;
      }
    },
    onClick(option) {
      this.sendData({
        Air: option.value,
        WdSpd: this.Pow ? this.WdSpd : this.Air === 1 ? this.WdSpd : 3,
        StHt: 0
      });
    },
    onHide() {
      this.SetPopup({ AirAutoPopup: false });
    }
  }
};
</script>

<style lang="scss">
.air-auto-popup {
  width: 100%;
  color: #404657;
  .gree-radio-list {
    .air-describe {
      font-size: 36px;
      color: #989898;
    }
    &.is-airauto {
      .gree-cell-item {
        .air-describe {
          font-size: 36px;
          color: #989898;
        }
        &:nth-child(2) {
          .air-title {
            padding-top: 20px;
          }
          .gree-cell-item-content {
            .btn-group {
              display: flex;
              height: 150px;
              transform: translateX(-96px);
              .btn {
                padding-left: 94px;
                .gree-check-base-box {
                  width: 224px;
                  height: 80px;
                  border: none;
                  display: flex;
                  align-items: center;
                  justify-content: center;
                  font-size: 44px;
                  background: rgba(152, 152, 152, 0.1);
                  border-radius: 40px;
                  &.is-checked {
                    color: #fff;
                    background: #71acf1;
                  }
                }
              }
            }
          }
          .gree-cell-item-right {
            position: absolute;
            top: 40px;
            right: 64px;
          }
        }
      }
    }
    .gree-radio-icon {
      .gree-icon.icon-font.checked {
        color: #71acf1;
      }
    }
  }
}
</style>
